@@ -9,7 +9,7 @@
 #
 package MooseX::RelatedClasses;
 {
-  $MooseX::RelatedClasses::VERSION = '0.005';
+  $MooseX::RelatedClasses::VERSION = '0.006';
 }
 
 # ABSTRACT: Parameterized role for related class attributes
@@ -23,7 +23,7 @@ use MooseX::Types::Common::String ':all';
 use MooseX::Types::LoadableClass ':all';
 use MooseX::Types::Perl ':all';
 use MooseX::Types::Moose ':all';
-use MooseX::Util 'with_traits';
+use MooseX::Util 'with_traits', 'find_meta';
 
 use Module::Find 'findallmod';
 
@@ -34,6 +34,20 @@ use String::RewritePrefix;
 #use Smart::Comments '###';
 #use autobox::JSON;
 
+use Moose::Exporter;
+Moose::Exporter->setup_import_methods(
+    with_meta => [ qw{ related_classes related_class } ],
+);
+
+
+sub related_class { goto \&related_classes }
+
+sub related_classes {
+    my ($meta, %args) = @_;
+
+    find_meta('MooseX::RelatedClasses')->apply($meta, %args);
+}
+
 
 parameter name  => (
     traits    => [Shortcuts],
@@ -175,7 +189,7 @@ __END__
 
 =encoding utf-8
 
-=for :stopwords Chris Weyl Parameterized
+=for :stopwords Chris Weyl Parameterized Namespacing
 
 =head1 NAME
 
@@ -183,31 +197,32 @@ MooseX::RelatedClasses - Parameterized role for related class attributes
 
 =head1 VERSION
 
-This document describes version 0.005 of MooseX::RelatedClasses - released May 09, 2013 as part of MooseX-RelatedClasses.
+This document describes version 0.006 of MooseX::RelatedClasses - released July 12, 2013 as part of MooseX-RelatedClasses.
 
 =head1 SYNOPSIS
 
-    # a related class...
-    package My::Framework::Thinger;
-    # ...
-
-    # our "parent" class...
-    package My::Framework;
-
-    use Moose;
-    use namespace::autoclean;
-
-    # with this...
+    # with this:
     with 'MooseX::RelatedClasses' => {
-        name => 'Thinger',
+        name => 'Thinger', namespace => undef,
     };
 
-    # ...we get:
+    # ...or this (preferred):
+    use MooseX::RelatedClasses;
+    related_class name => 'Thinger', namespace => undef;
+
+    # ...we get three attributes:
+    #
+    #   thinger_class
+    #   thinger_class_traits
+    #   original_thinger_class
+    #
+    # ...and they look like this:
+
     has thinger_class => (
-        traits     => [ Shortcuts ], # MooseX::AttributeShortcuts
-        is         => 'lazy',
-        isa        => LoadableClass, # MooseX::Types::LoadableClass
-        constraint => sub { $_->isa('Thinger') }, # MX::AttributeShortcuts
+        traits     => [ Shortcuts ],                # MooseX::AttributeShortcuts
+        is         => 'lazy',                       # MX::AttributeShortcuts
+        isa        => LoadableClass,                # MooseX::Types::LoadableClass
+        constraint => sub { $_->isa('Thinger') },   # MX::AttributeShortcuts
         builder    => sub { ... compose original class and traits ... },
     );
 
@@ -228,26 +243,6 @@ This document describes version 0.005 of MooseX::RelatedClasses - released May 0
         builder    => sub { 'My::Framework::Thinger' },
     );
 
-    # multiple related classes can be handled in one shot:
-    with 'MooseX::RelatedClasses' => {
-        names => [ qw{ Thinger Dinger Finger } ],
-    };
-
-    # if you're using this role and the name of the class is _not_ your
-    # related namespace, then you can specify it:
-    with 'MooseX::RelatedClasses' => {
-        # e.g. My::Framework::Recorder::Thinger
-        name      => 'Thinger',
-        namespace => 'My::Framework::Recorder',
-    };
-
-    # if you want to specify another class w/o any common namespace as
-    # related:
-    with 'MooseX::RelatedClasses' => {
-        namespace => undef,
-        name      => 'LWP::UserAgent',
-    };
-
 =head1 DESCRIPTION
 
 Have you ever built out a framework, or interface API of some sort, to
@@ -303,8 +298,9 @@ classes.  Defaults to false.
 
 The namespace our related classes live in.  If this is not given explicitly,
 the name of the consuming class will be used as the namespace.  If the
-consuming class is not available (e.g. it's being constructed by something
-other than a consumer), then this parameter is mandatory.
+consuming class' metaclass is not available (e.g. the role is being
+constructed by something other than a consumer), then this parameter is
+mandatory.
 
 This parameter will also accept an explicit 'undef'.  If this is the case,
 then related classes must be specified by their full name and it is an error
@@ -331,6 +327,81 @@ If true, attributes, accessors and builders will all be named according to the
 same rules L<MooseX::AttributeShortcuts> uses.  (That is, in general prefixed
 with an "_".)
 
+=head1 FUNCTIONS
+
+=head2 related_class()
+
+Synonym for L</related_classes()>.
+
+=head2 related_classes()
+
+Takes the same options that the role takes as parameters.  That means that this:
+
+    related_classes name => 'LWP::UserAgent', namespace => undef;
+
+...is effectively the same as:
+
+    with 'MooseX::RelatedClasses' => {
+        name      => 'LWP::UserAgent',
+        namespace => undef,
+    };
+
+=head1 EXAMPLES
+
+=head2 Multiple Related Classes at Once
+
+Use the L</names> option with an array reference of classes, and attribute
+sets will be built for all of them.
+
+    related_classes names => [ qw{ Thinger Dinger Finger } ];
+
+=head2 Namespaces / Namespacing
+
+Normally, related classes tend to be under the namespace of the class they
+are related to.  For example, let's say we have a class named C<TimeLords>.
+Related to this class are C<TimeLords::SoftwareWritten::Git>,
+C<TimeLords::Gallifrey> and C<TimeLords::Enemies::Daleks>.
+
+The C<TimeLords> package can start off like this, to include the proper
+related classes:
+
+    package TimeLords;
+
+    use Moose;
+    use timeandspace::autoclean;
+    use MooseX::RelatedClasses;
+
+    related_classes
+        names => [ qw{ Gallifrey Enemies::Daleks SoftwareWritten::Git } ],
+        ;
+
+And that will generate the expected related class attributes:
+
+    gallifrey_class
+    gallifrey_class_traits
+    original_gallifrey_class
+    enemies__daleks_class
+    enemies__daleks_class_traits
+    original_enemies__daleks_class
+    software_written__git_class
+    software_written__git_class_traits
+    original_software_written__git_class
+
+=head2 Related classes outside the namespace
+
+Occasionally you'll want to use something like L<LWP::UserAgent>, which has
+nothing to do with your class except that you use it, and would like to be
+able to easily tweak it on the fly.  This can be done with the C<undef>
+namespace:
+
+    related_class name => 'LWP::UserAgent', namespace => undef;
+
+This will cause the following related class attributes to be generated:
+
+    lwp__user_agent_class
+    lwp__user_agent_class_traits
+    original_lwp__user_agent_class
+
 =head1 INSPIRATION / MADNESS
 
 The L<Class::MOP> / L<Moose> MOP show the beginnings of this:  with attributes
